@@ -7,7 +7,7 @@ fn main() {
     let target =
         env::var("TARGET").expect("selinux-sys: Environment variable 'TARGET' was not defined.");
 
-    match get_target_os(&target).as_deref() {
+    match get_target_os(&target) {
         None => return, // Do not build anything for bare metal architectures.
 
         // This list must be kept synchronized with the cfg in `lib.rs`.
@@ -50,7 +50,7 @@ fn rerun_if_env_changed(name: &str, target: &str) {
     println!("cargo:rerun-if-env-changed={name}");
 }
 
-fn get_target_os(target: &str) -> Option<String> {
+fn get_target_os(target: &str) -> Option<&str> {
     let components: Vec<_> = target.split('-').collect();
     let os_index = match components.len() {
         2 => {
@@ -72,11 +72,11 @@ fn get_target_os(target: &str) -> Option<String> {
         _ => panic!("Unrecognized target triplet '{target}'"),
     };
 
-    Some(String::from(components[os_index]))
+    Some(components[os_index])
 }
 
 // See: https://github.com/rust-lang/rust-bindgen/issues/2136
-fn translate_rustc_target_to_clang(rustc_target: &str) -> Cow<str> {
+fn translate_rustc_target_to_clang(rustc_target: &str) -> Cow<'_, str> {
     if let Some(suffix) = rustc_target.strip_prefix("riscv32") {
         let suffix = suffix.trim_start_matches(|c| c != '-');
         Cow::Owned(format!("riscv32{suffix}"))
