@@ -128,8 +128,7 @@ impl CompilerSearchPaths {
         let output = child.wait_with_output()?;
 
         if !output.status.success() {
-            return Err(io::Error::new(
-                io::ErrorKind::Other,
+            return Err(io::Error::other(
                 "Compiler failed to print search directories",
             ));
         }
@@ -183,8 +182,7 @@ impl CompilerSearchPaths {
         let output = child.wait_with_output()?;
 
         if !output.status.success() {
-            return Err(io::Error::new(
-                io::ErrorKind::Other,
+            return Err(io::Error::other(
                 "Compiler failed to print search directories",
             ));
         }
@@ -197,10 +195,7 @@ impl CompilerSearchPaths {
             .map(str::trim)
             .map(|line| line.trim_start_matches('='))
             .ok_or_else(|| {
-                io::Error::new(
-                    io::ErrorKind::Other,
-                    "Compiler search directories format is unrecognized",
-                )
+                io::Error::other("Compiler search directories format is unrecognized")
             })?;
 
         let mut paths = Vec::with_capacity(8);
