@@ -1,6 +1,6 @@
-#![cfg(target_os = "linux")]
+#![cfg(any(target_os = "linux", target_os = "android"))]
 #![doc = include_str!("../README.md")]
-#![doc(html_root_url = "https://docs.rs/selinux-sys/0.6.14")]
+#![doc(html_root_url = "https://docs.rs/selinux-sys/0.6.15")]
 #![warn(unsafe_op_in_unsafe_fn)]
 #![allow(
     non_upper_case_globals,
